/* $Workfile: OtxApi.h $   $Revision: 8 $    $Modtime: 3/03/00 2:27p $  */
#ifndef OTX_API_H
#define OTX_API_H
/*******************************************************************************

  @doc PublicDspSdkApi OtxApi

  Odin TeleSystems Inc.

  SAA-1007-1 OTX DSP C54x Software Development Kit (SDK)

  DSP SDK API Functions

  @module
  OtxApi | DSK SDK API Function Prototypes

  @contents2
  OtxApi.h |

  @index func | OtxApi

  @contents2
  DSP SDK Functions (OtxApi.h) | DSP SDK Functions available for custom DSP Applications

  @head3 OtxApi Function Reference |

  @index func | OtxApi

*******************************************************************************/

#include "OtxDef.h"
#include "DspIoctl.h"

/*--------------------------------------------------------------------------*\
  API FUNCTION DEFINITIONS
\*--------------------------------------------------------------------------*/

/*******************************************************************************
  @func
    Run Standard OTX DSP SDK API Initializations. Calls 
    <f OtxDspInitProcessor>,
    <f OtxDspInitGlobalData>,
    <f OtxDspInitInterrupts>,
    <f OtxDspInitHostPortInterface>, 
    <f OtxDspInitHostPortInterface>, and
    <f OtxDspInitBufferedSerialPorts>.
*******************************************************************************/
void OtxDspInit(
  void                      /* @parm No parameters */
);

/*******************************************************************************
  @func
    Sets up the processor to the desired operating mode. Called by
    <f OtxDspInit>.
*******************************************************************************/
void OtxDspInitProcessor(
  void                      /* @parm No parameters */
);


/*******************************************************************************
  @func
    Initialize Standard Global Data. Called by <f OtxDspInit>.
*******************************************************************************/
void OtxDspInitGlobalData(
  void                      /* @parm No parameters */
);


/*******************************************************************************
  @func
    Initialize and unmask specified interrupts. Called by <f OtxDspInit>.
*******************************************************************************/
void OtxDspInitInterrupts(
  unsigned short valueIMR       /* @parm Interrupts to be unmasked */
);


/*******************************************************************************
  @func
    Initialize the Host Port Interface. Called by <f OtxDspInit>.
*******************************************************************************/
void OtxDspInitHostPortInterface(
  void                      /* @parm No parameters */
);


/*******************************************************************************
  @func
    Initialize the Buffered Serial Ports (BSP). Called by <f OtxDspInit>.
*******************************************************************************/
void OtxDspInitBufferedSerialPorts(
  void                     /* @parm No parameters */
);

/*******************************************************************************
  @func
    Verifies that the DSP SDK and the Host driver revisions match. Initializes
    the PLL to make it run at the maximum speed for this particular DSP.

    This function should be called when the OTXDSP_SDK_IO_START_PROGRAM IO code
    is sent from the host. 
    
*******************************************************************************/
short OtxDspStartProgram(
  OtxDspSdkIoInStartProgramS *pSin
);

/*******************************************************************************
  @func
    Resets the internal DSP timer to be used for timestamping of Host events.
    The timer interrupt frequency is 10.000MHz for ASM and PCI boards 
    and 10.036MHz for PCMCIA boards. The timer interrupt service routine is
    called when the TIM register is decremented to 0. The timer interrupt service 
    routine increments a 64 bit timestamp which is used the Host events.

    This function should be called when the OTXDSP_SDK_IO_INIT_TIMER IO code
    is sent from the host. 
*******************************************************************************/
short OtxDspInitTimer(
  void
);


/*******************************************************************************
  @func
    Begin a critical section.
    Disables global interrupts (by setting INTM) and returns the value of 
    INTM (before INTM was set)

  @xref
    <f OtxDspCriticalSectionEnd>
*******************************************************************************/
short OtxDspCriticalSectionBegin(
  void                     /* @parm No parameters */
);

/*******************************************************************************
  @func
    End a critical section.
    Enable global interrupts (if they were enabled when OtxDspCriticalSectionBegin
    was called).

  @xref
    <f OtxDspCriticalSectionBegin>
*******************************************************************************/
void OtxDspCriticalSectionEnd(
  short intmVal       /* @parm INTM value returned by <f OtxDspCriticalSectionBegin> */
);

/*******************************************************************************
  @func
    Completes an IO Control call from the host. Passes an
    arbitrary size of return data from a IO Control call back to the host.
*******************************************************************************/
void OtxDspCommandCompleteData(
  unsigned short hHandle,      /* @parm Handle to the user logical device */
  unsigned short *pData,       /* @parm Pointer to the data to be returned to the host driver */
  unsigned short dataLen       /* @parm Length of the data to be returned to the host driver */
); 

/*******************************************************************************
  @func
    Completes an IO Control call from the host. Passes a 
    return code from an IO Control call back to the host.
*******************************************************************************/
void OtxDspCommandCompleteRc(
  unsigned short hHandle,    /* @parm Handle to the user defined logical device */
  unsigned short nResult     /* @parm Result code to be passed to the host driver */
);

/*******************************************************************************
  @func
    Completes an IO Control call from the host. No data is passed back
    to the host.
*******************************************************************************/
void OtxDspCommandComplete(
  unsigned short hHandle    /* @parm Handle to the user defined logical device */
);


/*******************************************************************************
  @func
    Takes in a 14 bit 2-s complement value and returns a A-law compressed
    value ready to transmission (8-bits)
  @comm
    Every other bit is inverted (for transmission).
*******************************************************************************/
extern short OtxDspAlawCompress(
  short lawCompInput  /* @parm 14 bit 2-s complement value to be companded */
);


/*******************************************************************************
  @func
    Takes in a 14 bit 2-s complement value and returns a U-law compressed
    value ready to transmission (8-bits)
  @comm
    Value bits (0-6) are inverted
*******************************************************************************/
extern short OtxDspUlawCompress(
  short lawCompInput  /* @parm 14 bit 2-s complement value to be companded */
);



/*******************************************************************************
  @func
    Expands a U-law or A-law companded 8-bit sample and returns a 14-bit 2's
    complement value (in the 14 least significant bits of a 16-bit word)
  @comm
    Since a-law only has a range of -4196 .. x .. 4195, the value is multiplied
    by 2 before it is returned to make it a full scale 14-bit value.
*******************************************************************************/
extern short OtxDspLawExpand(
  short lawExpandInput,    /* @parm Sample to be expanded (8-bits sign magnitude value */
  short law                /* @parm Law (0 = u-law, 1 = A-law) */
);


/*--------------------------------------------------------------------------*\
  API CALL-BACK FUNCTIONS
\*--------------------------------------------------------------------------*/

/*******************************************************************************
  @func
    Generates a driver event for the host and copies the associated data
    to the HPI buffer.
*******************************************************************************/
short OtxDspSetHostEvent(
  unsigned short nEvent,         /* @parm Event to be send to the host */
  unsigned short hHandle,        /* @parm Handle to the user logical device sending the event */
  unsigned short nTaskRef,       /* @parm Associated Task Reference */
  unsigned short *pData,         /* @parm Pointer to the data to be sent to the host */
  unsigned short nDataLen        /* @parm Length of the data to be sent */
);


/*******************************************************************************
  @func
    Call-back routine called by the Interrupt Service Routine when the
    host has issued a command to the HPI and requests our attention.
  @comm
    This function is called from the Interrupt Service Routine.
    TO BE RE-IMPLEMENTED BY THE USER.
*******************************************************************************/
void OtxDspServiceIoControl(
  void                          /* @parm No parameters */
);


/*******************************************************************************
  @func
    Call-back routine call when we have receive interrupt from the
    Buffered Serial Port indicating the the receive buffer is either full or
    half-full.
  @comm
    This function is called from the Interrupt Service Routine
    TO BE RE-IMPLEMENTED BY THE USER.
*******************************************************************************/
void OtxDspServiceRxSerialPort(
  void                          /* @parm No parameters */
);


/*******************************************************************************
  @func
    Call-back routine call when we have transmit interrupt from the
    Buffered Serial Port indicating the the transmit buffer is either empty or
    half-empty.
  @comm
    This function is called from the Interrupt Service Routine
    TO BE RE-IMPLEMENTED BY THE USER.
*******************************************************************************/
void OtxDspServiceTxSerialPort(
  void                          /* @parm No parameters */
);

#endif /* OTX_API_H */
